@@ -7,7 +7,10 @@ from yalexs.lock import LockDoorStatus, LockStatus
 
 ACTION_LOCK_ONETOUCHLOCK = "onetouchlock"
 ACTION_LOCK_LOCK = "lock"
+ACTION_LOCK_LOCKING = "locking"
 ACTION_LOCK_UNLOCK = "unlock"
+ACTION_LOCK_UNLOCKING = "unlocking"
+ACTION_LOCK_JAMMED = "jammed"
 ACTION_DOOR_OPEN = "dooropen"
 ACTION_DOOR_CLOSED = "doorclosed"
 ACTION_DOORBELL_CALL_INITIATED = "doorbell_call_initiated"
@@ -35,6 +38,9 @@ ACTIVITY_ACTIONS_DOORBELL_VIEW = [ACTION_DOORBELL_CALL_INITIATED]
 ACTIVITY_ACTIONS_LOCK_OPERATION = [
     ACTION_LOCK_LOCK,
     ACTION_LOCK_UNLOCK,
+    ACTION_LOCK_LOCKING,
+    ACTION_LOCK_UNLOCKING,
+    ACTION_LOCK_JAMMED,
     ACTION_LOCK_ONETOUCHLOCK,
 ]
 ACTIVITY_ACTIONS_DOOR_OPERATION = [ACTION_DOOR_CLOSED, ACTION_DOOR_OPEN]
@@ -43,6 +49,9 @@ ACTIVITY_ACTION_STATES = {
     ACTION_LOCK_ONETOUCHLOCK: LockStatus.LOCKED,
     ACTION_LOCK_LOCK: LockStatus.LOCKED,
     ACTION_LOCK_UNLOCK: LockStatus.UNLOCKED,
+    ACTION_LOCK_LOCKING: LockStatus.LOCKING,
+    ACTION_LOCK_UNLOCKING: LockStatus.UNLOCKING,
+    ACTION_LOCK_JAMMED: LockStatus.JAMMED,
     ACTION_DOOR_OPEN: LockDoorStatus.OPEN,
     ACTION_DOOR_CLOSED: LockDoorStatus.CLOSED,
 }
